Use the REST API to start an import from a Git source repository.
Warning
Due to very low levels of usage and available alternatives, the Source Imports API has been retired. For more details and alternatives, see the changelog.
You can use these endpoints to start an import from a Git repository hosted with another service. This is the same functionality as the GitHub Importer. For more information, see Importing a repository with GitHub Importer. A typical source import would start the import and then (optionally) update the authors and/or update the preference for using Git LFS if large files exist in the import. You can also create a webhook that listens for the RepositoryImportEvent to find out the status of the import.
Note
These endpoints only support authentication using a personal access token (classic). For more information, see Managing your personal access tokens.
The following diagram provides a more detailed example:
+---------+ +--------+ +---------------------+
| Tooling | | GitHub | | Original Repository |
+---------+ +--------+ +---------------------+
| | |
| Start import | |
|----------------------------->| |
| | |
| | Download source data |
| |--------------------------------------------->|
| | Begin streaming data |
| |<---------------------------------------------|
| | |
| Get import progress | |
|----------------------------->| |
| "status": "importing" | |
|<-----------------------------| |
| | |
| Get commit authors | |
|----------------------------->| |
| | |
| Map a commit author | |
|----------------------------->| |
| | |
| | |
| | Finish streaming data |
| |<---------------------------------------------|
| | |
| | Rewrite commits with mapped authors |
| |------+ |
| | | |
| |<-----+ |
| | |
| | Update repository on GitHub |
| |------+ |
| | | |
| |<-----+ |
| | |
| Map a commit author | |
|----------------------------->| |
| | Rewrite commits with mapped authors |
| |------+ |
| | | |
| |<-----+ |
| | |
| | Update repository on GitHub |
| |------+ |
| | | |
| |<-----+ |
| | |
| Get large files | |
|----------------------------->| |
| | |
| opt_in to Git LFS | |
|----------------------------->| |
| | Rewrite commits for large files |
| |------+ |
| | | |
| |<-----+ |
| | |
| | Update repository on GitHub |
| |------+ |
| | | |
| |<-----+ |
| | |
| Get import progress | |
|----------------------------->| |
| "status": "complete" | |
|<-----------------------------| |
| | |
| | |
Note
Most endpoints use Authorization: Bearer <YOUR-TOKEN> and Accept: application/vnd.github+json headers, plus X-GitHub-Api-Version: 2026-03-10. Curl examples below omit these standard headers for brevity.
GET /repos/{owner}/{repo}/import
View the progress of an import.
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
Import status
This section includes details about the possible values of the status field of the Import Progress response.
An import that does not have errors will progress through these steps:
detecting - the "detection" step of the import is in progress because the request did not include a vcs parameter. The import is identifying the type of source control present at the URL.
importing - the "raw" step of the import is in progress. This is where commit data is fetched from the original repository. The import progress response will include commit_count (the total number of raw commits that will be imported) and percent (0 - 100, the current progress through the import).
mapping - the "rewrite" step of the import is in progress. This is where SVN branches are converted to Git branches, and where author updates are applied. The import progress response does not include progress information.
pushing - the "push" step of the import is in progress. This is where the importer updates the repository on GitHub. The import progress response will include push_percent, which is the percent value reported by git push when it is "Writing objects".
complete - the import is complete, and the repository is ready on GitHub.
If there are problems, you will see one of these in the status field:
auth_failed - the import requires authentication in order to connect to the original repository. To update authentication for the import, please see the Update an import section.
error - the import encountered an error. The import progress response will include the failed_step and an error message. Contact GitHub Support for more information.
detection_needs_auth - the importer requires authentication for the originating repository to continue detection. To update authentication for the import, please see the Update an import section.
detection_found_nothing - the importer didn't recognize any source control at the URL. To resolve, Cancel the import and retry with the correct URL.
detection_found_multiple - the importer found several projects or repositories at the provided URL. When this is the case, the Import Progress response will also include a project_choices field with the possible project choices as values. To update project choice, please see the Update an import section.
The project_choices field
When multiple projects are found at the provided URL, the response hash will include a project_choices field, the value of which is an array of hashes each representing a project choice. The exact key/value pairs of the project hashes will differ depending on the version control type.
Git LFS related fields
This section includes details about Git LFS related fields that may be present in the Import Progress response.
use_lfs - describes whether the import has been opted in or out of using Git LFS. The value can be opt_in, opt_out, or undecided if no action has been taken.
has_large_files - the boolean value describing whether files larger than 100MB were found during the importing step.
large_files_size - the total size in gigabytes of files larger than 100MB found in the originating repository.
large_files_count - the total number of files larger than 100MB found in the originating repository. To see a list of these files, make a "Get Large Files" request.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
200 - OK
404 - Resource not found
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X GET \
https://api.github.com/repos/OWNER/REPO/import
Response schema (Status: 200):
vcs: required, string or nulluse_lfs: booleanvcs_url: required, stringsvc_root: stringtfvc_project: stringstatus: required, string, enum: auth, error, none, detecting, choose, auth_failed, importing, mapping, waiting_to_push, pushing, complete, setup, unknown, detection_found_multiple, detection_found_nothing, detection_needs_authstatus_text: string or nullfailed_step: string or nullerror_message: string or nullimport_percent: integer or nullcommit_count: integer or nullpush_percent: integer or nullhas_large_files: booleanlarge_files_size: integerlarge_files_count: integerproject_choices: array of objects:
vcs: stringtfvc_project: stringhuman_name: stringmessage: stringauthors_count: integer or nullurl: required, string, format: urihtml_url: required, string, format: uriauthors_url: required, string, format: urirepository_url: required, string, format: urisvn_root: stringPUT /repos/{owner}/{repo}/import
Start a source import to a GitHub repository using GitHub Importer.
Importing into a GitHub repository with GitHub Actions enabled is not supported and will
return a status 422 Unprocessable Entity response.
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
vcs_url (string) (required)
The URL of the originating repository.
vcs (string)
The originating VCS type. Without this parameter, the import job will take additional time to detect the VCS type before beginning the import. This detection step will be reflected in the response.
Can be one of: subversion, git, mercurial, tfvc
vcs_username (string)
If authentication is required, the username to provide to vcs_url.
vcs_password (string)
If authentication is required, the password to provide to vcs_url.
tfvc_project (string)
For a tfvc import, the name of the project that is being imported.
201 - Created
404 - Resource not found
422 - Validation failed, or the endpoint has been spammed.
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X PUT \
https://api.github.com/repos/OWNER/REPO/import \
-d '{
"vcs": "subversion",
"vcs_url": "http://svn.example.com/svn/myproject",
"vcs_username": "octocat",
"vcs_password": "secret"
}'
Response schema (Status: 201):
Same response schema as Get an import status.
PATCH /repos/{owner}/{repo}/import
An import can be updated with credentials or a project choice by passing in the appropriate parameters in this API
request. If no parameters are provided, the import will be restarted.
Some servers (e.g. TFS servers) can have several projects at a single URL. In those cases the import progress will
have the status detection_found_multiple and the Import Progress response will include a project_choices array.
You can select the project to import by providing one of the objects in the project_choices array in the update request.
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
vcs_username (string)
The username to provide to the originating repository.
vcs_password (string)
The password to provide to the originating repository.
vcs (string)
The type of version control system you are migrating from.
Can be one of: subversion, tfvc, git, mercurial
tfvc_project (string)
For a tfvc import, the name of the project that is being imported.
200 - OK
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X PATCH \
https://api.github.com/repos/OWNER/REPO/import \
-d '{
"vcs_username": "octocat",
"vcs_password": "secret"
}'
Response schema (Status: 200):
Same response schema as Get an import status.
Request:
curl -L \
-X PATCH \
https://api.github.com/repos/OWNER/REPO/import \
-d '{
"vcs": "tfvc",
"tfvc_project": "project1",
"human_name": "project1 (tfs)"
}'
Response schema (Status: 200):
Same response schema as Get an import status.
Request:
curl -L \
-X PATCH \
https://api.github.com/repos/OWNER/REPO/import
Response schema (Status: 200):
Same response schema as Get an import status.
DELETE /repos/{owner}/{repo}/import
Stop an import for a repository.
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
204 - No Content
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X DELETE \
https://api.github.com/repos/OWNER/REPO/import
Response schema (Status: 204):
GET /repos/{owner}/{repo}/import/authors
Each type of source control system represents authors in a different way. For example, a Git commit author has a display name and an email address, but a Subversion commit author just has a username. The GitHub Importer will make the author information valid, but the author might not be correct. For example, it will change the bare Subversion username hubot into something like hubot hubot@12341234-abab-fefe-8787-fedcba987654.
This endpoint and the Map a commit author endpoint allow you to provide correct Git author information.
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
since (integer)
A user ID. Only return users with an ID greater than this ID.
200 - OK
404 - Resource not found
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X GET \
https://api.github.com/repos/OWNER/REPO/import/authors
Response schema (Status: 200):
Array of Porter Author:
id: required, integerremote_id: required, stringremote_name: required, stringemail: required, stringname: required, stringurl: required, string, format: uriimport_url: required, string, format: uriPATCH /repos/{owner}/{repo}/import/authors/{author_id}
Update an author's identity for the import. Your application can continue updating authors any time before you push
new commits to the repository.
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
author_id (integer) (required)
email (string)
The new Git author email.
name (string)
The new Git author name.
200 - OK
404 - Resource not found
422 - Validation failed, or the endpoint has been spammed.
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X PATCH \
https://api.github.com/repos/OWNER/REPO/import/authors/AUTHOR_ID \
-d '{
"email": "hubot@github.com",
"name": "Hubot the Robot"
}'
Response schema (Status: 200):
id: required, integerremote_id: required, stringremote_name: required, stringemail: required, stringname: required, stringurl: required, string, format: uriimport_url: required, string, format: uriGET /repos/{owner}/{repo}/import/large_files
List files larger than 100MB found during the import
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
200 - OK
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X GET \
https://api.github.com/repos/OWNER/REPO/import/large_files
Response schema (Status: 200):
Array of Porter Large File:
ref_name: required, stringpath: required, stringoid: required, stringsize: required, integerPATCH /repos/{owner}/{repo}/import/lfs
You can import repositories from Subversion, Mercurial, and TFS that include files larger than 100MB. This ability
is powered by Git LFS.
You can learn more about our LFS feature and working with large files on our help
site.
Warning
Endpoint closing down notice: Due to very low levels of usage and available alternatives, this endpoint is closing down and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the changelog.
accept (string)application/vnd.github+json is recommended.owner (string) (required)
The account owner of the repository. The name is not case sensitive.
repo (string) (required)
The name of the repository without the .git extension. The name is not case sensitive.
use_lfs (string) (required)opt_in, opt_out200 - OK
422 - Validation failed, or the endpoint has been spammed.
503 - Unavailable due to service under maintenance.
Request:
curl -L \
-X PATCH \
https://api.github.com/repos/OWNER/REPO/import/lfs \
-d '{
"use_lfs": "opt_in"
}'
Response schema (Status: 200):
Same response schema as Get an import status.